@@ -1,6 +1,6 @@
 import sys
 from dataclasses import dataclass, field
-from typing import Any, Callable, Dict, Generic, TypeVar
+from typing import Any, Callable, Dict, FrozenSet, Generic, TypeVar
 
 T = TypeVar("T")
 W = TypeVar("W")
